==> fred_dnscheck-0.1.1-py3-none-any.whl: dnscheck/tests/test_cli.py <==
import signal
from unittest.mock import call

import pytest
from click.testing import CliRunner
from pytest_mock import MockerFixture
from testfixtures import LogCapture

from dnscheck.cli import cli
from dnscheck.settings import APP


@pytest.fixture(autouse=True)
def _unload_settings():
    """Unload settings so it can be loaded on CLI startup."""
    APP.settings = None  # type: ignore[assignment]


def test_sync(mocker: MockerFixture):
    sync_nssets = mocker.patch("dnscheck.process.nssets.sync")
    runner = CliRunner()
    result = runner.invoke(cli, ["sync"])

    assert result.exception is None
    assert result.exit_code == 0
    assert result.output == ""
    assert sync_nssets.mock_calls == [call(batch_size=1000)]


def test_sync_batch_size(mocker: MockerFixture):
    sync_nssets = mocker.patch("dnscheck.process.nssets.sync")
    runner = CliRunner()
    result = runner.invoke(cli, ["sync", "--batch-size", "42"])

    assert result.exception is None
    assert result.exit_code == 0
    assert result.output == ""
    assert sync_nssets.mock_calls == [call(batch_size=42)]


class RunTest:
    @pytest.fixture(autouse=True)
    def _mock_process(self, mocker: MockerFixture):
        self.domain_checks_start = mocker.patch("dnscheck.process.domain_checks.start")
        self.domain_checks_finish = mocker.patch("dnscheck.process.domain_checks.finish")
        self.nsset_checks_start = mocker.patch("dnscheck.process.nsset_checks.start")
        self.nsset_checks_evaluate = mocker.patch("dnscheck.process.nsset_checks.evaluate")
        self.nsset_checks_finish = mocker.patch("dnscheck.process.nsset_checks.finish")

    def test_keyboard_interrupt(self, mocker: MockerFixture):
        mocker.patch("time.sleep", side_effect=[None, KeyboardInterrupt])

        with LogCapture() as logs:
            runner = CliRunner()
            result = runner.invoke(cli, ["run"])

        assert result.exception is None
        assert result.exit_code == 0
        assert result.output == ""
        assert self.domain_checks_finish.call_count == 2
        assert self.nsset_checks_evaluate.call_count == 2
        assert self.nsset_checks_start.call_count == 2
        assert self.domain_checks_start.call_count == 2
        assert self.nsset_checks_finish.call_count == 2
        logs.check(
            ("dnscheck.cli", "INFO", "Starting dnscheck daemon"),
            ("dnscheck.cli", "INFO", "Stopping dnscheck daemon"),
        )

    def test_loop_delay(self, mocker: MockerFixture):
        sleep_mock = mocker.patch("time.sleep", side_effect=KeyboardInterrupt)

        runner = CliRunner()
        result = runner.invoke(cli, ["run", "--loop-delay", "42"])

        assert result.exception is None
        assert result.exit_code == 0
        assert result.output == ""
        sleep_mock.assert_called_once_with(42)

    def test_sigterm(self, mocker: MockerFixture):
        def _emit_sigterm():
            signal.raise_signal(signal.SIGTERM)

        self.nsset_checks_evaluate.side_effect = _emit_sigterm

        with LogCapture() as logs:
            runner = CliRunner()
            result = runner.invoke(cli, ["run"])

        assert result.exception is None
        assert result.exit_code == 0
        assert result.output == ""
        self.domain_checks_finish.assert_called_once()
        self.nsset_checks_evaluate.assert_called_once()  # sigterm emitted
        self.nsset_checks_start.assert_not_called()
        self.domain_checks_start.assert_not_called()
        self.nsset_checks_finish.assert_not_called()
        logs.check(
            ("dnscheck.cli", "INFO", "Starting dnscheck daemon"),
            ("dnscheck.cli", "INFO", "Captured signal SIGTERM, stopping dnscheck daemon"),
            ("dnscheck.cli", "INFO", "Dnscheck daemon has been gracefully stopped"),
        )

==> fred_dnscheck-0.2.1-py3-none-any.whl: dnscheck/tests/test_cli.py <==
import signal
from unittest.mock import call

import pytest
from click.testing import CliRunner
from pytest_mock import MockerFixture
from testfixtures import LogCapture

from dnscheck.cli import cli
from dnscheck.settings import APP


@pytest.fixture(autouse=True)
def _unload_settings():
    """Unload settings so it can be loaded on CLI startup."""
    APP.settings = None  # type: ignore[assignment]


def test_sync(mocker: MockerFixture):
    sync_nssets = mocker.patch("dnscheck.process.nssets.sync")
    runner = CliRunner()
    result = runner.invoke(cli, ["sync"])

    assert result.exception is None
    assert result.exit_code == 0
    assert result.output == ""
    assert sync_nssets.mock_calls == [call(batch_size=1000)]


def test_sync_batch_size(mocker: MockerFixture):
    sync_nssets = mocker.patch("dnscheck.process.nssets.sync")
    runner = CliRunner()
    result = runner.invoke(cli, ["sync", "--batch-size", "42"])

    assert result.exception is None
    assert result.exit_code == 0
    assert result.output == ""
    assert sync_nssets.mock_calls == [call(batch_size=42)]


class RunTest:
    @pytest.fixture(autouse=True)
    def _mock_process(self, mocker: MockerFixture):
        self.domain_checks_start = mocker.patch("dnscheck.process.domain_checks.start")
        self.domain_checks_finish = mocker.patch("dnscheck.process.domain_checks.finish")
        self.nsset_checks_start = mocker.patch("dnscheck.process.nsset_checks.start")
        self.nsset_checks_finish = mocker.patch("dnscheck.process.nsset_checks.finish")

    def test_keyboard_interrupt(self, mocker: MockerFixture):
        mocker.patch("time.sleep", side_effect=[None, KeyboardInterrupt])

        with LogCapture() as logs:
            runner = CliRunner()
            result = runner.invoke(cli, ["run"])

        assert result.exception is None
        assert result.exit_code == 0
        assert result.output == ""
        assert self.domain_checks_finish.call_count == 2
        assert self.nsset_checks_start.call_count == 2
        assert self.domain_checks_start.call_count == 2
        assert self.nsset_checks_finish.call_count == 2
        logs.check(
            ("dnscheck.cli", "INFO", "Starting dnscheck daemon"),
            ("dnscheck.cli", "INFO", "Stopping dnscheck daemon"),
        )

    def test_loop_delay(self, mocker: MockerFixture):
        sleep_mock = mocker.patch("time.sleep", side_effect=KeyboardInterrupt)

        runner = CliRunner()
        result = runner.invoke(cli, ["run", "--loop-delay", "42"])

        assert result.exception is None
        assert result.exit_code == 0
        assert result.output == ""
        sleep_mock.assert_called_once_with(42)

    def test_sigterm(self, mocker: MockerFixture):
        def _emit_sigterm():
            signal.raise_signal(signal.SIGTERM)

        self.nsset_checks_start.side_effect = _emit_sigterm

        with LogCapture() as logs:
            runner = CliRunner()
            result = runner.invoke(cli, ["run"])

        assert result.exception is None
        assert result.exit_code == 0
        assert result.output == ""
        self.domain_checks_finish.assert_called_once()
        self.nsset_checks_start.assert_called_once()  # sigterm emitted
        self.domain_checks_start.assert_not_called()
        self.nsset_checks_finish.assert_not_called()
        logs.check(
            ("dnscheck.cli", "INFO", "Starting dnscheck daemon"),
            ("dnscheck.cli", "INFO", "Captured signal SIGTERM, stopping dnscheck daemon"),
            ("dnscheck.cli", "INFO", "Dnscheck daemon has been gracefully stopped"),
        )
